package
module
Version:
v0.0.0-...-e7cdcf6
Opens a new window with list of versions in this module.
Published: Dec 6, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package xlsx 提供 excel 工具封装, 仅实现简单填值。更复杂的还是要使用 excelize
CellName 按行、列(均从 0 开始)对应的单元格名称
Xlsx 提供 Excel 简易操作
func (x *Xlsx) Excelize() *excelize.File
Excelize 获取内置的 *excelize.File 对象
Source Files
¶
Click to show internal directories.
Click to hide internal directories.